@@ -11,7 +11,7 @@ import time
 
 import numpy
 import psutil
-from PySide2 import QtCore
+from PySide6 import QtCore
 
 from hyperborea.namedprocess import NamedProcess
 from hyperborea.proxy import DeviceLoggerAdapter, RemoteToLocalLogHandler
@@ -105,6 +105,7 @@ class CalcRunner:
         self.mean_ringbuffers = [None] * channel_count
         self.plot_ringbuffers = [None] * channel_count
         self.fft_ringbuffers = [None] * channel_count
+        self.channel_buffers = [None] * channel_count
 
         channel_decoders = {}
         for i, stream_decoder in enumerate(self.device_decoder.decoders):
@@ -136,6 +137,9 @@ class CalcRunner:
             channel_info.fft_sample_len, channel_decoder.subchannels)
         self.fft_ringbuffers[channel_index] = fft_rb
 
+        buffer = list()
+        self.channel_buffers[channel_index] = buffer
+
         downsample = channel_info.downsample_factor != 1
 
         def callback(_counter, data, samples, subchannels):
@@ -147,7 +151,7 @@ class CalcRunner:
             fft_rb.extend(d)
             mean_rb.extend(d)
             if channel_pipe:
-                channel_pipe.send(d)
+                buffer.append(d)
 
         channel_decoder.set_callback(callback)
 
@@ -405,6 +409,15 @@ class CalcRunner:
                             self.plot_change(*ctrl[1:])
                         elif ctrl[0] == CalcControl.RESET_LOST_PACKETS:
                             self.reset_lost_packets()
+                for channel_index, buffer in enumerate(self.channel_buffers):
+                    if buffer:
+                        channel_pipe = self.channel_pipes[channel_index]
+                        if channel_pipe:
+                            # NOTE: no locking concerns because only the
+                            # decoder callbacks extend the buffer
+                            d = numpy.concatenate(buffer)
+                            buffer.clear()
+                            channel_pipe.send(d)
         except Exception:
             self.logger.exception("Unhandled exception in calc process run")
         finally:
