@@ -391,6 +391,20 @@ def get_device_mode(device, device_info, incrementer):
     yield d
 
 
+def hash_is_valid(hash):
+    if not hash:
+        return False
+
+    lowercase_string = hash.lower()
+
+    if all(c == 'f' for c in lowercase_string):
+        return False  # all ones
+    elif all(c == '0' for c in lowercase_string):
+        return False  # all zeros
+
+    return True
+
+
 def get_device_info_actual(device, device_logger, allow_reconnect, diskcache,
                            progress_pipe, setting_getters, nvm_getters):
     incrementer = Incrementer(progress_pipe, device_logger)
@@ -406,6 +420,7 @@ def get_device_info_actual(device, device_logger, allow_reconnect, diskcache,
         build_info = device.get_build_info()
         build_date = device.get_build_date()
         nvm_hash = try_optional(device.get_nvm_hash)
+        nvm_modified = try_optional(device.get_nvm_modified)
         setting_hash = try_optional(device.get_setting_hash)
 
         finished_commands = 4
@@ -414,7 +429,7 @@ def get_device_info_actual(device, device_logger, allow_reconnect, diskcache,
         # load setting_info from cache, if applicable
         setting_key = (serial_number, protocol_type, build_info, build_date,
                        setting_hash)
-        if setting_hash is None and not allow_reconnect:
+        if not hash_is_valid(setting_hash) and not allow_reconnect:
             # not a simple reconnect, and the device is old-style
             setting_info = {}
         elif diskcache is not None:
@@ -426,7 +441,7 @@ def get_device_info_actual(device, device_logger, allow_reconnect, diskcache,
 
         # load nvm_info from cache, if applicable
         nvm_key = (serial_number, nvm_hash)
-        if nvm_hash is None:
+        if not hash_is_valid(nvm_hash) or nvm_modified is True:
             nvm_info = {}
         elif diskcache is not None:
             nvm_info = diskcache.get(nvm_key, default={})
@@ -441,6 +456,7 @@ def get_device_info_actual(device, device_logger, allow_reconnect, diskcache,
             'build_info': build_info,
             'build_date': build_date,
             'nvm_hash': nvm_hash,
+            'nvm_modified': nvm_modified,
             'setting_hash': setting_hash,
             'location_string': device.get_location_string(),
             'library_protocol_version': asphodel.protocol_version_string,
@@ -507,8 +523,9 @@ def get_device_info_actual(device, device_logger, allow_reconnect, diskcache,
         finally:
             # store back to cache
             if diskcache is not None:
-                diskcache.set(setting_key, setting_info)
-                if nvm_hash is not None:
+                if hash_is_valid(setting_hash):
+                    diskcache.set(setting_key, setting_info)
+                if hash_is_valid(nvm_hash) and nvm_modified is False:
                     diskcache.set(nvm_key, nvm_info)
     finally:
         if progress_pipe:
@@ -530,7 +547,6 @@ default_setting_getters = [
     single_call('commit_id', "get_commit_id", optional=True),
     single_call('repo_branch', "get_repo_branch", optional=True),
     single_call('repo_name', "get_repo_name", optional=True),
-    single_call('nvm_modified', "get_nvm_modified", optional=True),
     get_custom_enums,
     get_setting_categories,
     get_streams,
