@@ -204,10 +204,14 @@ class StreamWriter:
             startupinfo.wShowWindow = subprocess.SW_HIDE
             self.popen_extras = {
                 'startupinfo': startupinfo,
-                'creationflags': subprocess.CREATE_NEW_PROCESS_GROUP}
+                'creationflags': (subprocess.CREATE_NEW_PROCESS_GROUP |
+                                  subprocess.BELOW_NORMAL_PRIORITY_CLASS),
+            }
         else:
             # hyperborea.proxy has this process in a different process group
-            self.popen_extras = {}
+            self.popen_extras = {
+                'preexec_fn': lambda: os.nice(10)
+            }
 
         # find 7zip (7za, 7zr, 7z)
         compressor_path = self._find_7zip()
